import _regeneratorRuntime from "@babel/runtime/regenerator";
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import React, { useState, useEffect, useRef, useCallback } from 'react';
import SuiButton from '@s-ui/react-atom-button';
import SuiModal from '@s-ui/react-molecule-modal';
import SuiNotification from '@s-ui/react-molecule-notification';
import IconClose from './iconClose';
import { I18N } from './settings';
var CLASS = 'sui-TcfFirstLayer';
var SCROLL_TO_ACCEPT = 250;
export default function TcfFirstLayer(_ref) {
  var _ref$lang = _ref.lang,
      lang = _ref$lang === void 0 ? 'es' : _ref$lang,
      logo = _ref.logo,
      isMobile = _ref.isMobile,
      isTablet = _ref.isTablet,
      getVendorList = _ref.getVendorList,
      saveUserConsent = _ref.saveUserConsent,
      openSecondLayer = _ref.openSecondLayer,
      openCookiepolicyLayer = _ref.openCookiepolicyLayer;

  var _useState = useState(true),
      show = _useState[0],
      setShow = _useState[1];

  var i18n = I18N[lang];
  var handleCookiePolicyLayerClick = useCallback(function () {
    cookiesPolicyLink.current && cookiesPolicyLink.current.removeEventListener('click', handleCookiePolicyLayerClick);
    openCookiepolicyLayer();
  });
  var cookiesPolicyLink = useRef();
  var ref = useRef(null);
  var textRef = useCallback(function (node) {
    if (ref.current) {
      ref.current = null;
    }

    if (node) {
      cookiesPolicyLink.current = node.querySelector("." + CLASS + "-body-info-link");

      if (cookiesPolicyLink) {
        cookiesPolicyLink.current.addEventListener('click', handleCookiePolicyLayerClick);
      }

      ref.current = node;
    }
  }, [handleCookiePolicyLayerClick]);
  var initialYOffset;

  var checkScroll = function checkScroll() {
    if (initialYOffset - window.pageYOffset >= SCROLL_TO_ACCEPT || initialYOffset - window.pageYOffset <= -SCROLL_TO_ACCEPT) {
      handleSaveExitClick();
    }
  };

  useEffect(function () {
    initialYOffset = window.pageYOffset;
    document.addEventListener('scroll', checkScroll, {
      passive: true
    });
  }, []);

  var handleSettingsClick = function handleSettingsClick() {
    openSecondLayer();
  };

  var handleSaveExitClick = /*#__PURE__*/function () {
    var _ref2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
      var _yield$getVendorList, VLPurposes, VLVendors, VLSpecialFeatures, userConsent, purpose, vendor, specialFeatures, key, _key, _key2;

      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              _context.next = 2;
              return getVendorList({
                language: lang
              });

            case 2:
              _yield$getVendorList = _context.sent;
              VLPurposes = _yield$getVendorList.purposes;
              VLVendors = _yield$getVendorList.vendors;
              VLSpecialFeatures = _yield$getVendorList.specialFeatures;
              userConsent = {
                purpose: {
                  consents: {},
                  legitimateInterests: {}
                },
                vendor: {
                  consents: {},
                  legitimateInterests: {}
                },
                specialFeatures: {}
              };
              purpose = userConsent.purpose, vendor = userConsent.vendor, specialFeatures = userConsent.specialFeatures;

              for (key in VLPurposes) {
                purpose.consents[key] = true;
                purpose.legitimateInterests[key] = true;
              }

              for (_key in VLVendors) {
                vendor.consents[_key] = true;
                vendor.legitimateInterests[_key] = true;
              }

              for (_key2 in VLSpecialFeatures) {
                specialFeatures[_key2] = true;
              }

              handleCloseModal();
              saveUserConsent(userConsent);

            case 13:
            case "end":
              return _context.stop();
          }
        }
      }, _callee);
    }));

    return function handleSaveExitClick() {
      return _ref2.apply(this, arguments);
    };
  }();

  var handleCloseModal = function handleCloseModal() {
    document.removeEventListener('scroll', checkScroll);
    setShow(false);
  };

  var Content = function Content(_ref3) {
    var modalType = _ref3.modalType;
    var baseBodyClass = CLASS + "-body";
    var bodyClasses = isTablet ? baseBodyClass + " " + baseBodyClass + "--footer " + baseBodyClass + "--tablet" : baseBodyClass + " " + baseBodyClass + "--footer";
    var baseButtonsClass = CLASS + "-buttons";
    var buttonsClasses = isTablet ? baseButtonsClass + " " + baseButtonsClass + "--footer " + baseButtonsClass + "--tablet" : baseButtonsClass + " " + baseButtonsClass + "--footer";
    return /*#__PURE__*/React.createElement("div", {
      className: modalType ? "" + baseBodyClass : bodyClasses
    }, /*#__PURE__*/React.createElement("span", {
      className: baseBodyClass + "-info",
      ref: textRef,
      dangerouslySetInnerHTML: {
        __html: i18n.BODY
      }
    }), /*#__PURE__*/React.createElement("div", {
      className: modalType ? "" + baseButtonsClass : buttonsClasses
    }, /*#__PURE__*/React.createElement(SuiButton, {
      onClick: handleSettingsClick,
      design: "outline"
    }, i18n.CONFIGURE_BUTTON), /*#__PURE__*/React.createElement(SuiButton, {
      onClick: handleSaveExitClick
    }, i18n.CONTINUE_NAVIGATION_BUTTON)));
  };

  return /*#__PURE__*/React.createElement("div", {
    className: CLASS
  }, isMobile && /*#__PURE__*/React.createElement(SuiModal, {
    isOpen: show,
    closeOnOutsideClick: true,
    closeOnEscKeyDown: true,
    header: /*#__PURE__*/React.createElement("img", {
      className: CLASS + "-logo",
      src: logo,
      alt: "logo"
    }),
    iconClose: /*#__PURE__*/React.createElement(IconClose, {
      "class": CLASS + "-icon-close"
    }),
    onClose: handleCloseModal,
    fitContent: true
  }, /*#__PURE__*/React.createElement(Content, {
    modalType: true
  })), !isMobile && /*#__PURE__*/React.createElement("div", {
    className: CLASS + "-notification"
  }, /*#__PURE__*/React.createElement(SuiNotification, {
    position: "bottom",
    autoClose: "manual",
    show: show,
    showCloseButton: false,
    variation: "positive",
    type: "system"
  }, /*#__PURE__*/React.createElement(Content, null))));
}
TcfFirstLayer.displayName = 'TcfFirstLayer';